@@ -7,14 +7,15 @@ class Projects:
   def __init__(self, conn: Connection):
     self.conn = conn
 
-  async def find_by_name(self, name):
+  async def find_by_organization_and_name(self, organization_name, project_name):
     result = await self.conn.query_control(
       variables={
-        'name': format_entity_name(name),
+        'organizationName': format_entity_name(organization_name),
+        'projectName': format_entity_name(project_name),
       },
       query="""
-        query ProjectByName($name: String!) {
-          projectByName(name: $name) {
+        query ProjectByOrganizationAndName($organizationName: String!, $projectName: String!) {
+          projectByOrganizationAndName(organizationName: $organizationName, projectName: $projectName) {
             projectID
             name
             displayName
@@ -27,14 +28,11 @@ class Projects:
             streams {
               name
             }
-            users {
-              username
-            }
           }
         }
       """
     )
-    return result['projectByName']
+    return result['projectByOrganizationAndName']
 
   async def create(
     self,
@@ -68,12 +66,6 @@ class Projects:
             photoURL
             createdOn
             updatedOn
-            users {
-              userID
-              name
-              username
-              photoURL
-            }
           }
         }
       """
@@ -114,30 +106,25 @@ class Projects:
     )
     return result['updateProject']
 
-  async def update_organization(self, project_id, organization_id):
+  async def get_member_permissions(self, project_id):
     result = await self.conn.query_control(
       variables={
         'projectID': project_id,
-        'organizationID': organization_id,
       },
       query="""
-        mutation UpdateProjectOrganization($projectID: UUID!, $organizationID: UUID!) {
-          updateProjectOrganization(projectID: $projectID, organizationID: $organizationID) {
-            projectID
+        query ProjectMembers($projectID: UUID!) {
+          projectMembers(projectID: $projectID) {
+            userID
+            name
             displayName
-            public
-            site
-            description
-            photoURL
-            updatedOn
-            organization {
-              name
-            }
+            view
+            create
+            admin
           }
         }
       """
     )
-    return result['updateProjectOrganization']
+    return result['projectMembers']
 
   async def delete(self, project_id):
     result = await self.conn.query_control(
@@ -151,44 +138,3 @@ class Projects:
       """
     )
     return result['deleteProject']
-
-  async def add_user(self, project_id, username, view, create, admin):
-    result = await self.conn.query_control(
-      variables={
-        'username': username,
-        'projectID': project_id,
-        'view': view,
-        'create': create,
-        'admin': admin,
-      },
-      query="""
-        mutation AddUserToProject($username: String!, $projectID: UUID!, $view: Boolean!, $create: Boolean!, $admin: Boolean!) {
-          addUserToProject(username: $username, projectID: $projectID, view: $view, create: $create, admin: $admin) {
-            userID
-            username
-            name
-            createdOn
-            projects {
-              name
-            }
-            readQuota
-            writeQuota
-          }
-        }
-      """
-    )
-    return result['addUserToProject']
-
-  async def remove_user(self, project_id, user_id):
-    result = await self.conn.query_control(
-      variables={
-        'userID': user_id,
-        'projectID': project_id,
-      },
-      query="""
-        mutation RemoveUserFromProject($userID: UUID!, $projectID: UUID!) {
-          removeUserFromProject(userID: $userID, projectID: $projectID)
-        }
-      """
-    )
-    return result['removeUserFromProject']
